<?php
use Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge;
use Shopware\trus1TrustedShopsBadge\Components\Configuration;

/**
 * Class Shopware_Controllers_Backend_TrustedShopsBadge
 *
 * @package Shopware\Plugins\trus1TrustedShopsBadge\Controllers
 * @author    Trusted Shops GmbH
 * @copyright 2017 Trusted Shops GmbH
 * @license   http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 * @link      http://www.trustedshops.de/
 */
class Shopware_Controllers_Backend_TrustedShopsBadge extends Shopware_Controllers_Backend_ExtJs
{

    /**
     *
     */
    public function init()
    {
        parent::init();
    }

    /**
     * @return Configuration
     */
    private function getTsConfig()
    {
        $modelManager = Shopware()->Models();

        $locale1 = $this->get('locale');
        return new Configuration($modelManager, $locale1);
    }

    /**
     *
     */
    public function setSettingsAction()
    {
        $request = $this->Request();
        $trustedShopsParams = $request->getParams();
        //preventting of saving the tsid with blank spaces
        $trustedShopsParams['trustedShopsId'] = trim($trustedShopsParams['trustedShopsId'], ' ');

        if($trustedShopsParams['expertMode']) {
            $trustedShopsParams['trustedShopsNotInStockDeliveryTime'] =  $trustedShopsParams['trustedShopsNotInStockDeliveryTimeExpert'];
            $trustedShopsParams['trustedShopsInStockDeliveryTime'] = $trustedShopsParams['trustedShopsInStockDeliveryTimeExpert'];
            $trustedShopsParams['prodReviewStickerTabName'] = $trustedShopsParams['prodReviewStickerTabNameExpert'];
        }
        unset($trustedShopsParams['trustedShopsInStockDeliveryTimeExpert'],$trustedShopsParams['trustedShopsNotInStockDeliveryTimeExpert'], $trustedShopsParams['prodReviewStickerTabNameExpert']);

        /* @var TrustedShopsBadge $trustedShopsModel */
        $trustedShopsModel = $this->getModelManager()->getRepository('Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge')
            ->findOneBy(array('shopId' => $trustedShopsParams['shopId']));

        if ($trustedShopsModel) {
            $trustedShopsModel->fromArray($trustedShopsParams);
        } else {
            $trustedShopsModel = new TrustedShopsBadge;
            $trustedShopsModel->fromArray($trustedShopsParams);
        }

        $this->getModelManager()->persist($trustedShopsModel);
        $this->getModelManager()->flush($trustedShopsModel);
        $this->View()->assign(array('data' => $trustedShopsParams['shopId'], 'success' => true,));

        $this->View()->assign(array('data' => $trustedShopsParams['shopId'], 'success' => true,));
        try {
            $cacheManager = Shopware()->Container()->get('shopware.cache_manager');
        } catch (Exception $e) {
        }
        $cacheManager->clearHttpCache();
    }

    /**
     *
     */
    public function getSettingsAction()
    {
        $shopId = $this->Request()->getParam('shopId');
        $data = $this->getTsConfig()->getSettings($shopId);
        if($data['expertMode']) {
            $data['trustedShopsNotInStockDeliveryTimeExpert'] =  $data['trustedShopsNotInStockDeliveryTime'];
            $data['trustedShopsInStockDeliveryTimeExpert'] = $data['trustedShopsInStockDeliveryTime'];
            $data['prodReviewStickerTabNameExpert'] = $data['prodReviewStickerTabName'];
        }
        $this->View()->assign(array('success' => true, 'data' => $data));
    }

    public function resetSettingsAction()
    {
        $shopId = $this->Request()->getParam('shopId');
        $tsData['id'] = $shopId;
        $tsData['shopId'] = $shopId;
        $tsData['trustedShopsId'] = '';
        $tsData['locale'] = $this->get('locale');
        $tsData['badgeVariant'] = 'reviews';
        $tsData['expertMode'] = false;
        $tsData['collectReviewsAndShowGuarantee'] = false;
        $tsData['collectRatings'] = false;
        $tsData['collectRatingsExpert'] = false;
        $tsData['trustedShopsShowReviewStickerActive'] = false;
        $tsData['prodReviewStickerTabName'] = 'Trusted Shops Bewertungen';
        $tsData['prodReviewStickerTabNameExpert'] = 'Trusted Shops Bewertungen';
        $tsData['trustedShopsShowReviewStickerCode'] = '<script type="text/javascript">
      _tsProductReviewsConfig = {
            tsid: \'%tsid%\',
            sku: [\'%sku%\'],
            variant: \'productreviews\',
            borderColor: \'#0DBEDC\',
            backgroundColor: \'#ffffff\',
            element: \'#ts_product_sticker\',
            locale: \'%locale%\',
            starColor: \'#FFDC0F\',
            starSize: \'15px\',
            richSnippets: \'off\',
            ratingSummary: \'false\',
            maxHeight: \'1200px\',
            hideEmptySticker: \'false\',
            introtext: \'What our customers say about us:\'
            /* optional */
      };
      var scripts = document.getElementsByTagName(\'SCRIPT\'),
      me = scripts[scripts.length - 1];
      var _ts = document.createElement(\'SCRIPT\');
      _ts.type = \'text/javascript\';
      _ts.async = true;
      _ts.charset = \'utf-8\';
      _ts.src =\'//widgets.trustedshops.com/reviews/tsSticker/tsProductSticker.js\';
      me.parentNode.insertBefore(_ts, me);
      _tsProductReviewsConfig.script = _ts;
    </script>';

        $tsData['trustedShopsShowRatingsStarsActive'] = false;
        $tsData['trustedShopsShowRatingsStarsCode'] = '
    <script type="text/javascript" src="//widgets.trustedshops.com/reviews/tsSticker/tsProductStickerSummary.js"></script>
    <script> 
    var summaryBadge = new productStickerSummary();
    summaryBadge.showSummary(
    {
    \'tsId\': "%tsid%",
    \'sku\': [\'%sku%\'],
    \'element\': \'#ts_product_widget_position\',
    \'starColor\' : \'#FFDC0F\',
    \'starSize\' : \'14px\',
    \'fontSize\' : \'12px\',
    \'showRating\' : \'true\' ,
    \'scrollToReviews\' : \'false\' ,
    \'enablePlaceholder\': \'true\'
    }
    );
    </script> 
    ';

        $tsData['trustedShopsTrustBadgeCode'] = '<script type="text/javascript">
        (function () {
            var _tsid = \'%tsid%\';
            _tsConfig = {
              \'yOffset\': \'0\', /* offset from page bottom */
              \'variant\': \'reviews\', /* default, reviews, custom, custom_reviews */
              \'customElementId\': \'\', /* required for variants custom and custom_reviews */
              \'trustcardDirection\': \'\', /* for custom variants: topRight, topLeft, bottomRight, bottomLeft */
              \'disableResponsive\': \'false\', /* deactivate responsive behaviour */
              \'disableTrustbadge\': \'false\' /* deactivate trustbadge */
    
            };
            var _ts = document.createElement(\'script\');
            _ts.type = \'text/javascript\';
            _ts.charset = \'utf-8\';
            _ts.async = true;
            _ts.src = \'//widgets.trustedshops.com/js/\' + _tsid + \'.js\';
            var __ts = document.getElementsByTagName(\'script\')[0];
            __ts.parentNode.insertBefore(_ts, __ts);
          })();
    </script>';

        $tsData['yOffset'] = 0;
        $tsData['prodStickerBorderColor'] = '#0DBEDC';
        $tsData['prodStickerStarColor'] = '#FFDC0F';
        $tsData['starColor'] = '#FFDC0F';
        $tsData['starSize'] = 15;
        $tsData['fontSize'] = 12;
        $tsData['reviewStickerBackgroundColor'] = '#FFFFFF';
        $tsData['reviewStickerStarSize'] = 15;
        $tsData['trustedShopsInStockDeliveryTime'] = 4;
        $tsData['trustedShopsNotInStockDeliveryTime'] = 10;

        $tsData['customerRatingsActive'] = false;
        $tsData['customerRatingsActiveExpert'] = false;
        $tsData['customerRatingsExpertCode'] = ' <script type="text/javascript">
                        _tsRatingConfig = {
                            tsid: \'%tsid%\',
                            variant: \'testimonial\',
                            theme: \'light\',
                            reviews: \'5\',
                            betterThan: \'3.0\',
                            richSnippets: \'off\',
                            backgroundColor: \'#ffdc0f\',
                            linkColor: \'#000000\',
                            quotationMarkColor: \'#FFFFFF\',
                            fontFamily: \'Arial\',
                            reviewMinLength: \'10\'
                        };
                        var scripts = document.getElementsByTagName(\'SCRIPT\'),
                            me = scripts[scripts.length - 1];
                        var _ts = document.createElement(\'SCRIPT\');
                        _ts.type = \'text/javascript\';
                        _ts.async = true;
                        _ts.src =
                            \'//widgets.trustedshops.com/reviews/tsSticker/tsSticker.js\';
                        me.parentNode.insertBefore(_ts, me);
                        _tsRatingConfig.script = _ts;
                    </script>';
        $tsData['customerRatingsFontFamily'] = 'Arial';
        $tsData['customerRatingsReviews'] = 5;
        $tsData['customerRatingsBetterThan'] = '3.0';
        $tsData['customerRatingsBackgroundColor'] = '#ffdc0f';
        $tsData['richSnippetsActive'] = false;
        $tsData['richSnippetsLocations'] = '';
        $tsData['reviewStickerSelector'] = '';
        $tsData['reviewStarsSelector'] = '';
        $tsData['customerReviewsSelector'] = '';
        $tsData['richSnippetsLocationsExpert'] = '';
        $tsData['richSnippetsActiveExpert'] = false;
        $tsData['richSnippetsExpertCode'] = '<script type="application/ld+json">
                {
                "@context": "http://schema.org",
                "@type": "Organization",
                "name": "%shopname%",
                "aggregateRating" : {
                "@type": "AggregateRating",
                "ratingValue" : "%result%",
                "bestRating" : "%max%",
                "ratingCount" : "%count%"
                }
                }
            </script>';


        /* @var TrustedShopsBadge $trustedShopsModel */
        $trustedShopsModel = $this->getModelManager()->getRepository('Shopware\CustomModels\TrustedShopsBadge\TrustedShopsBadge')
            ->findOneBy(array('shopId' => $shopId));
        if ($trustedShopsModel) {
            $trustedShopsModel->fromArray($tsData);
        } else {
            $trustedShopsModel = new TrustedShopsBadge;
            $trustedShopsModel->fromArray($tsData);
        }
        $this->getModelManager()->persist($trustedShopsModel);
        $this->getModelManager()->flush($trustedShopsModel);

        $this->View()->assign(array('data' => $shopId, 'success' => true));
    }
}